@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-from hypothesis_auto import auto_pytest_magic  # type: ignore[import]
-
 import tinytext
 
 
@@ -13,6 +11,3 @@ def test_something() -> None:
 
     # Assert
     assert tiny == "ᶦᶰᵗᵒ ᵗᶦᶰᶦᵉʳ ᵗᵉˣᵗ"
-
-
-auto_pytest_magic(tinytext.tinytext)
